from ._yaxis import YAxisValidator
from ._xaxis import XAxisValidator
from ._width import WidthValidator
from ._violinmode import ViolinmodeValidator
from ._violingroupgap import ViolingroupgapValidator
from ._violingap import ViolingapValidator
from ._updatemenudefaults import UpdatemenuValidator
from ._updatemenus import UpdatemenusValidator
from ._titlefont import TitlefontValidator
from ._title import TitleValidator
from ._ternary import TernaryValidator
from ._template import TemplateValidator
from ._spikedistance import SpikedistanceValidator
from ._sliderdefaults import SliderValidator
from ._sliders import SlidersValidator
from ._showlegend import ShowlegendValidator
from ._shapedefaults import ShapeValidator
from ._shapes import ShapesValidator
from ._separators import SeparatorsValidator
from ._selectdirection import SelectdirectionValidator
from ._scene import SceneValidator
from ._radialaxis import RadialAxisValidator
from ._polar import PolarValidator
from ._plot_bgcolor import PlotBgcolorValidator
from ._piecolorway import PiecolorwayValidator
from ._paper_bgcolor import PaperBgcolorValidator
from ._orientation import OrientationValidator
from ._modebar import ModebarValidator
from ._margin import MarginValidator
from ._mapbox import MapboxValidator
from ._legend import LegendValidator
from ._imagedefaults import ImageValidator
from ._images import ImagesValidator
from ._hovermode import HovermodeValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverdistance import HoverdistanceValidator
from ._hidesources import HidesourcesValidator
from ._hiddenlabelssrc import HiddenlabelssrcValidator
from ._hiddenlabels import HiddenlabelsValidator
from ._height import HeightValidator
from ._grid import GridValidator
from ._geo import GeoValidator
from ._font import FontValidator
from ._extendpiecolors import ExtendpiecolorsValidator
from ._dragmode import DragmodeValidator
from ._direction import DirectionValidator
from ._datarevision import DatarevisionValidator
from ._colorway import ColorwayValidator
from ._clickmode import ClickmodeValidator
from ._calendar import CalendarValidator
from ._boxmode import BoxmodeValidator
from ._boxgroupgap import BoxgroupgapValidator
from ._boxgap import BoxgapValidator
from ._barnorm import BarnormValidator
from ._barmode import BarmodeValidator
from ._bargroupgap import BargroupgapValidator
from ._bargap import BargapValidator
from ._autosize import AutosizeValidator
from ._annotationdefaults import AnnotationValidator
from ._annotations import AnnotationsValidator
from ._angularaxis import AngularAxisValidator
