from ._visible import VisibleValidator
from ._uid import UidValidator
from ._tickfont import TickfontValidator
from ._stream import StreamValidator
from ._sortpaths import SortpathsValidator
from ._name import NameValidator
from ._line import LineValidator
from ._labelfont import LabelfontValidator
from ._hoveron import HoveronValidator
from ._hoverinfo import HoverinfoValidator
from ._domain import DomainValidator
from ._dimensiondefaults import DimensionValidator
from ._dimensions import DimensionsValidator
from ._countssrc import CountssrcValidator
from ._counts import CountsValidator
from ._bundlecolors import BundlecolorsValidator
from ._arrangement import ArrangementValidator
