from ._zaxis import ZAxisValidator
from ._yaxis import YAxisValidator
from ._xaxis import XAxisValidator
from ._hovermode import HovermodeValidator
from ._dragmode import DragmodeValidator
from ._domain import DomainValidator
from ._camera import CameraValidator
from ._bgcolor import BgcolorValidator
from ._aspectratio import AspectratioValidator
from ._aspectmode import AspectmodeValidator
from ._annotationdefaults import AnnotationValidator
from ._annotations import AnnotationsValidator
